"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    index_id: str,
    name: str,
    s3_path: Dict,
    role_arn: str,
    description: str = None,
    tags: List = None,
    file_format: str = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an new set of frequently asked question (FAQ) questions and answers.

    Args:
        index_id(str): The identifier of the index that contains the FAQ.
        name(str): The name that should be associated with the FAQ.
        description(str, optional): A description of the FAQ. Defaults to None.
        s3_path(Dict): The S3 location of the FAQ input data.
        role_arn(str): The Amazon Resource Name (ARN) of a role with permission to access the S3 bucket that contains the FAQs. For more information, see IAM Roles for Amazon Kendra.
        tags(List, optional): A list of key-value pairs that identify the FAQ. You can use the tags to identify and organize your resources and to control access to resources. Defaults to None.
        file_format(str, optional): The format of the input file. You can choose between a basic CSV format, a CSV format that includes customs attributes in a header, and a JSON format that includes custom attributes. The format must match the format of the file stored in the S3 bucket identified in the S3Path parameter. For more information, see Adding questions and answers. Defaults to None.
        client_token(str, optional): A token that you provide to identify the request to create a FAQ. Multiple calls to the CreateFaqRequest operation with the same client token will create only one FAQ. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.faq.create(
                ctx, index_id=value, name=value, s3_path=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.faq.create index_id=value, name=value, s3_path=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="create_faq",
        op_kwargs={
            "IndexId": index_id,
            "Name": name,
            "Description": description,
            "S3Path": s3_path,
            "RoleArn": role_arn,
            "Tags": tags,
            "FileFormat": file_format,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, id_: str, index_id: str) -> None:
    r"""
    **Autogenerated function**

    Removes an FAQ from an index.

    Args:
        id_(str): The identifier of the FAQ to remove.
        index_id(str): The index to remove the FAQ from.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.faq.delete(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.faq.delete id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="delete_faq",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )


async def describe(hub, ctx, id_: str, index_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about an FAQ list.

    Args:
        id_(str): The unique identifier of the FAQ.
        index_id(str): The identifier of the index that contains the FAQ.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.faq.describe(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.faq.describe id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="describe_faq",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    accelerator_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Describes information over a provided set of accelerators belonging to an account.

    Args:
        accelerator_ids(List, optional):  The IDs of the accelerators to describe. . Defaults to None.
        filters(List, optional):  One or more filters. Filter names and values are case-sensitive. Valid filter names are: accelerator-types: can provide a list of accelerator type names to filter for. instance-id: can provide a list of EC2 instance ids to filter for. . Defaults to None.
        max_results(int, optional):  The total number of items to return in the command's output. If the total number of items available is more than the value specified, a NextToken is provided in the command's output. To resume pagination, provide the NextToken value in the starting-token argument of a subsequent command. Do not use the NextToken response element directly outside of the AWS CLI. . Defaults to None.
        next_token(str, optional):  A token to specify where to start paginating. This is the NextToken from a previously truncated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elastic_inference.accelerator.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elastic_inference.accelerator.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elastic-inference",
        operation="describe_accelerators",
        op_kwargs={
            "acceleratorIds": accelerator_ids,
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(hub, ctx, ip: str, warmup_percentage: int) -> Dict:
    r"""
    **Autogenerated function**

    Args:
        ip(str): The dedicated IP address that you want to update the warm-up attributes for.
        warmup_percentage(int): The warm-up percentage that you want to associate with the dedicated IP address.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.dedicated_ip.warmup_attribute.put_multiple(
                ctx, ip=value, warmup_percentage=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.dedicated_ip.warmup_attribute.put_multiple ip=value, warmup_percentage=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_dedicated_ip_warmup_attributes",
        op_kwargs={"Ip": ip, "WarmupPercentage": warmup_percentage},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    customer_gateway_id: str,
    type_: str,
    vpn_gateway_id: str = None,
    transit_gateway_id: str = None,
    dry_run: bool = None,
    options: Dict = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a VPN connection between an existing virtual private gateway or transit gateway and a customer gateway. The supported connection type is ipsec.1. The response includes information that you need to give to your network administrator to configure your customer gateway.  We strongly recommend that you use HTTPS when calling this operation because the response contains sensitive cryptographic information for configuring your customer gateway device.  If you decide to shut down your VPN connection for any reason and later create a new VPN connection, you must reconfigure your customer gateway with the new information returned from this call. This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        customer_gateway_id(str): The ID of the customer gateway.
        type_(str): The type of VPN connection (ipsec.1).
        vpn_gateway_id(str, optional): The ID of the virtual private gateway. If you specify a virtual private gateway, you cannot specify a transit gateway. Defaults to None.
        transit_gateway_id(str, optional): The ID of the transit gateway. If you specify a transit gateway, you cannot specify a virtual private gateway. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        options(Dict, optional): The options for the VPN connection. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the VPN connection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.init.create(
                ctx, customer_gateway_id=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.init.create customer_gateway_id=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_vpn_connection",
        op_kwargs={
            "CustomerGatewayId": customer_gateway_id,
            "Type": type_,
            "VpnGatewayId": vpn_gateway_id,
            "TransitGatewayId": transit_gateway_id,
            "DryRun": dry_run,
            "Options": options,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(hub, ctx, vpn_connection_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified VPN connection. If you're deleting the VPC and its associated components, we recommend that you detach the virtual private gateway from the VPC and delete the VPC before deleting the VPN connection. If you believe that the tunnel credentials for your VPN connection have been compromised, you can delete the VPN connection and create a new one that has new keys, without needing to delete the VPC or virtual private gateway. If you create a new VPN connection, you must reconfigure the customer gateway device using the new configuration information returned with the new VPN connection ID. For certificate-based authentication, delete all AWS Certificate Manager (ACM) private certificates used for the AWS-side tunnel endpoints for the VPN connection before deleting the VPN connection.

    Args:
        vpn_connection_id(str): The ID of the VPN connection.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.init.delete(ctx, vpn_connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.init.delete vpn_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_vpn_connection",
        op_kwargs={"VpnConnectionId": vpn_connection_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    vpn_connection_ids: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your VPN connections. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        filters(List, optional): One or more filters.    customer-gateway-configuration - The configuration information for the customer gateway.    customer-gateway-id - The ID of a customer gateway associated with the VPN connection.    state - The state of the VPN connection (pending | available | deleting | deleted).    option.static-routes-only - Indicates whether the connection has static routes only. Used for devices that do not support Border Gateway Protocol (BGP).    route.destination-cidr-block - The destination CIDR block. This corresponds to the subnet used in a customer data center.    bgp-asn - The BGP Autonomous System Number (ASN) associated with a BGP device.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    type - The type of VPN connection. Currently the only supported type is ipsec.1.    vpn-connection-id - The ID of the VPN connection.    vpn-gateway-id - The ID of a virtual private gateway associated with the VPN connection.    transit-gateway-id - The ID of a transit gateway associated with the VPN connection.  . Defaults to None.
        vpn_connection_ids(List, optional): One or more VPN connection IDs. Default: Describes your VPN connections. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpn_connections",
        op_kwargs={
            "Filters": filters,
            "VpnConnectionIds": vpn_connection_ids,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub,
    ctx,
    vpn_connection_id: str,
    transit_gateway_id: str = None,
    customer_gateway_id: str = None,
    vpn_gateway_id: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the customer gateway or the target gateway of an AWS Site-to-Site VPN connection. To modify the target gateway, the following migration options are available:   An existing virtual private gateway to a new virtual private gateway   An existing virtual private gateway to a transit gateway   An existing transit gateway to a new transit gateway   An existing transit gateway to a virtual private gateway   Before you perform the migration to the new gateway, you must configure the new gateway. Use CreateVpnGateway to create a virtual private gateway, or CreateTransitGateway to create a transit gateway. This step is required when you migrate from a virtual private gateway with static routes to a transit gateway.  You must delete the static routes before you migrate to the new gateway. Keep a copy of the static route before you delete it. You will need to add back these routes to the transit gateway after the VPN connection migration is complete. After you migrate to the new gateway, you might need to modify your VPC route table. Use CreateRoute and DeleteRoute to make the changes described in VPN Gateway Target Modification Required VPC Route Table Updates in the AWS Site-to-Site VPN User Guide.  When the new gateway is a transit gateway, modify the transit gateway route table to allow traffic between the VPC and the AWS Site-to-Site VPN connection. Use CreateTransitGatewayRoute to add the routes.  If you deleted VPN static routes, you must add the static routes to the transit gateway route table. After you perform this operation, the AWS VPN endpoint's IP addresses on the AWS side and the tunnel options remain intact. Your AWS Site-to-Site VPN connection will be temporarily unavailable for a brief period while we provision the new endpoints.

    Args:
        vpn_connection_id(str): The ID of the VPN connection.
        transit_gateway_id(str, optional): The ID of the transit gateway. Defaults to None.
        customer_gateway_id(str, optional): The ID of the customer gateway at your end of the VPN connection. Defaults to None.
        vpn_gateway_id(str, optional): The ID of the virtual private gateway at the AWS side of the VPN connection. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpn.connection.init.modify(ctx, vpn_connection_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpn.connection.init.modify vpn_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpn_connection",
        op_kwargs={
            "VpnConnectionId": vpn_connection_id,
            "TransitGatewayId": transit_gateway_id,
            "CustomerGatewayId": customer_gateway_id,
            "VpnGatewayId": vpn_gateway_id,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, host_id_set: List, offering_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Preview a reservation purchase with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This is a preview of the PurchaseHostReservation action and does not result in the offering being purchased.

    Args:
        host_id_set(List): The IDs of the Dedicated Hosts with which the reservation is associated.
        offering_id(str): The offering ID of the reservation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.reservation.purchase_preview.get(
                ctx, host_id_set=value, offering_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.reservation.purchase_preview.get host_id_set=value, offering_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_host_reservation_purchase_preview",
        op_kwargs={"HostIdSet": host_id_set, "OfferingId": offering_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, core_device_thing_name: str, entries: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Disassociate a list of client devices from a core device. After you disassociate a client device from a core device, the client device won't be able to use cloud discovery to retrieve the core device's connectivity information and certificates.

    Args:
        entries(List, optional): The list of client devices to disassociate. Defaults to None.
        core_device_thing_name(str): The name of the core device. This is also the name of the IoT thing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrassv2.disassociate_client_device_from_core_device.batch(
                ctx, core_device_thing_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrassv2.disassociate_client_device_from_core_device.batch core_device_thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrassv2",
        operation="batch_disassociate_client_device_from_core_device",
        op_kwargs={"entries": entries, "coreDeviceThingName": core_device_thing_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation removes the transfer lock on the domain (specifically the clientTransferProhibited status) to allow domain transfers. We recommend you refrain from performing this action unless you intend to transfer the domain to a different registrar. Successful submission returns an operation ID that you can use to track the progress and completion of the action. If the request is not completed successfully, the domain registrant will be notified by email.

    Args:
        domain_name(str): The name of the domain that you want to remove the transfer lock for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.transfer.lock.disable(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.transfer.lock.disable domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="disable_domain_transfer_lock",
        op_kwargs={"DomainName": domain_name},
    )


async def enable(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation sets the transfer lock on the domain (specifically the clientTransferProhibited status) to prevent domain transfers. Successful submission returns an operation ID that you can use to track the progress and completion of the action. If the request is not completed successfully, the domain registrant will be notified by email.

    Args:
        domain_name(str): The name of the domain that you want to set the transfer lock for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.domain.transfer.lock.enable(
                ctx, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.domain.transfer.lock.enable domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="enable_domain_transfer_lock",
        op_kwargs={"DomainName": domain_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets the logging options. NOTE: use of this command is not recommended. Use GetV2LoggingOptions instead.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.logging_option.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.logging_option.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="get_logging_options", op_kwargs={}
    )


async def set_(hub, ctx, logging_options_payload: Dict) -> None:
    r"""
    **Autogenerated function**

    Sets the logging options. NOTE: use of this command is not recommended. Use SetV2LoggingOptions instead.

    Args:
        logging_options_payload(Dict): The logging options payload.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.logging_option.set(ctx, logging_options_payload=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.logging_option.set logging_options_payload=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="set_logging_options",
        op_kwargs={"loggingOptionsPayload": logging_options_payload},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    db_instance_identifier: str,
    db_instance_class: str,
    engine: str,
    db_name: str = None,
    allocated_storage: int = None,
    master_username: str = None,
    master_user_password: str = None,
    db_security_groups: List = None,
    vpc_security_group_ids: List = None,
    availability_zone: str = None,
    db_subnet_group_name: str = None,
    preferred_maintenance_window: str = None,
    db_parameter_group_name: str = None,
    backup_retention_period: int = None,
    preferred_backup_window: str = None,
    port: int = None,
    multi_az: bool = None,
    engine_version: str = None,
    auto_minor_version_upgrade: bool = None,
    license_model: str = None,
    iops: int = None,
    option_group_name: str = None,
    character_set_name: str = None,
    publicly_accessible: bool = None,
    tags: List = None,
    db_cluster_identifier: str = None,
    storage_type: str = None,
    tde_credential_arn: str = None,
    tde_credential_password: str = None,
    storage_encrypted: bool = None,
    kms_key_id: str = None,
    domain: str = None,
    copy_tags_to_snapshot: bool = None,
    monitoring_interval: int = None,
    monitoring_role_arn: str = None,
    domain_iam_role_name: str = None,
    promotion_tier: int = None,
    timezone: str = None,
    enable_iam_database_authentication: bool = None,
    enable_performance_insights: bool = None,
    performance_insights_kms_key_id: str = None,
    enable_cloudwatch_logs_exports: List = None,
    deletion_protection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB instance.

    Args:
        db_name(str, optional): Not supported. Defaults to None.
        db_instance_identifier(str): The DB instance identifier. This parameter is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: mydbinstance .
        allocated_storage(int, optional): Not supported by Neptune. Defaults to None.
        db_instance_class(str): The compute and memory capacity of the DB instance, for example, db.m4.large. Not all DB instance classes are available in all Amazon Regions.
        engine(str): The name of the database engine to be used for this instance. Valid Values: neptune .
        master_username(str, optional): Not supported by Neptune. Defaults to None.
        master_user_password(str, optional): Not supported by Neptune. Defaults to None.
        db_security_groups(List, optional): A list of DB security groups to associate with this DB instance. Default: The default DB security group for the database engine. Defaults to None.
        vpc_security_group_ids(List, optional): A list of EC2 VPC security groups to associate with this DB instance. Not applicable. The associated list of EC2 VPC security groups is managed by the DB cluster. For more information, see CreateDBCluster. Default: The default EC2 VPC security group for the DB subnet group's VPC. Defaults to None.
        availability_zone(str, optional):  The EC2 Availability Zone that the DB instance is created in Default: A random, system-chosen Availability Zone in the endpoint's Amazon Region.  Example: us-east-1d   Constraint: The AvailabilityZone parameter can't be specified if the MultiAZ parameter is set to true. The specified Availability Zone must be in the same Amazon Region as the current endpoint. Defaults to None.
        db_subnet_group_name(str, optional): A DB subnet group to associate with this DB instance. If there is no DB subnet group, then it is a non-VPC DB instance. Defaults to None.
        preferred_maintenance_window(str, optional): The time range each week during which system maintenance can occur, in Universal Coordinated Time (UTC).  Format: ddd:hh24:mi-ddd:hh24:mi  The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Region, occurring on a random day of the week. Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun. Constraints: Minimum 30-minute window. Defaults to None.
        db_parameter_group_name(str, optional): The name of the DB parameter group to associate with this DB instance. If this argument is omitted, the default DBParameterGroup for the specified engine is used. Constraints:   Must be 1 to 255 letters, numbers, or hyphens.   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens  . Defaults to None.
        backup_retention_period(int, optional): The number of days for which automated backups are retained. Not applicable. The retention period for automated backups is managed by the DB cluster. For more information, see CreateDBCluster. Default: 1 Constraints:   Must be a value from 0 to 35   Cannot be set to 0 if the DB instance is a source to Read Replicas  . Defaults to None.
        preferred_backup_window(str, optional):  The daily time range during which automated backups are created. Not applicable. The daily time range for creating automated backups is managed by the DB cluster. For more information, see CreateDBCluster. Defaults to None.
        port(int, optional): The port number on which the database accepts connections. Not applicable. The port is managed by the DB cluster. For more information, see CreateDBCluster.  Default: 8182  Type: Integer. Defaults to None.
        multi_az(bool, optional): Specifies if the DB instance is a Multi-AZ deployment. You can't set the AvailabilityZone parameter if the MultiAZ parameter is set to true. Defaults to None.
        engine_version(str, optional): The version number of the database engine to use. Currently, setting this parameter has no effect. Defaults to None.
        auto_minor_version_upgrade(bool, optional): Indicates that minor engine upgrades are applied automatically to the DB instance during the maintenance window. Default: true . Defaults to None.
        license_model(str, optional): License model information for this DB instance.  Valid values: license-included | bring-your-own-license | general-public-license . Defaults to None.
        iops(int, optional): The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for the DB instance. Defaults to None.
        option_group_name(str, optional):  (Not supported by Neptune) . Defaults to None.
        character_set_name(str, optional):  (Not supported by Neptune) . Defaults to None.
        publicly_accessible(bool, optional): This flag should no longer be used. Defaults to None.
        tags(List, optional): The tags to assign to the new instance. Defaults to None.
        db_cluster_identifier(str, optional): The identifier of the DB cluster that the instance will belong to. For information on creating a DB cluster, see CreateDBCluster. Type: String. Defaults to None.
        storage_type(str, optional): Specifies the storage type to be associated with the DB instance. Not applicable. Storage is managed by the DB Cluster. Defaults to None.
        tde_credential_arn(str, optional): The ARN from the key store with which to associate the instance for TDE encryption. Defaults to None.
        tde_credential_password(str, optional): The password for the given ARN from the key store in order to access the device. Defaults to None.
        storage_encrypted(bool, optional): Specifies whether the DB instance is encrypted. Not applicable. The encryption for DB instances is managed by the DB cluster. For more information, see CreateDBCluster. Default: false. Defaults to None.
        kms_key_id(str, optional): The Amazon KMS key identifier for an encrypted DB instance. The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are creating a DB instance with the same Amazon account that owns the KMS encryption key used to encrypt the new DB instance, then you can use the KMS key alias instead of the ARN for the KM encryption key. Not applicable. The KMS key identifier is managed by the DB cluster. For more information, see CreateDBCluster. If the StorageEncrypted parameter is true, and you do not specify a value for the KmsKeyId parameter, then Amazon Neptune will use your default encryption key. Amazon KMS creates the default encryption key for your Amazon account. Your Amazon account has a different default encryption key for each Amazon Region. Defaults to None.
        domain(str, optional): Specify the Active Directory Domain to create the instance in. Defaults to None.
        copy_tags_to_snapshot(bool, optional): True to copy all tags from the DB instance to snapshots of the DB instance, and otherwise false. The default is false. Defaults to None.
        monitoring_interval(int, optional): The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB instance. To disable collecting Enhanced Monitoring metrics, specify 0. The default is 0. If MonitoringRoleArn is specified, then you must also set MonitoringInterval to a value other than 0. Valid Values: 0, 1, 5, 10, 15, 30, 60 . Defaults to None.
        monitoring_role_arn(str, optional): The ARN for the IAM role that permits Neptune to send enhanced monitoring metrics to Amazon CloudWatch Logs. For example, arn:aws:iam:123456789012:role/emaccess. If MonitoringInterval is set to a value other than 0, then you must supply a MonitoringRoleArn value. Defaults to None.
        domain_iam_role_name(str, optional): Specify the name of the IAM role to be used when making API calls to the Directory Service. Defaults to None.
        promotion_tier(int, optional): A value that specifies the order in which an Read Replica is promoted to the primary instance after a failure of the existing primary instance.  Default: 1 Valid Values: 0 - 15. Defaults to None.
        timezone(str, optional): The time zone of the DB instance. Defaults to None.
        enable_iam_database_authentication(bool, optional): Not supported by Neptune (ignored). Defaults to None.
        enable_performance_insights(bool, optional):  (Not supported by Neptune) . Defaults to None.
        performance_insights_kms_key_id(str, optional):  (Not supported by Neptune) . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of log types that need to be enabled for exporting to CloudWatch Logs. Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB instance has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. See Deleting a DB Instance. DB instances in a DB cluster can be deleted even when deletion protection is enabled in their parent DB cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.instance.create(
                ctx, db_instance_identifier=value, db_instance_class=value, engine=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.instance.create db_instance_identifier=value, db_instance_class=value, engine=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="create_db_instance",
        op_kwargs={
            "DBName": db_name,
            "DBInstanceIdentifier": db_instance_identifier,
            "AllocatedStorage": allocated_storage,
            "DBInstanceClass": db_instance_class,
            "Engine": engine,
            "MasterUsername": master_username,
            "MasterUserPassword": master_user_password,
            "DBSecurityGroups": db_security_groups,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "AvailabilityZone": availability_zone,
            "DBSubnetGroupName": db_subnet_group_name,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "DBParameterGroupName": db_parameter_group_name,
            "BackupRetentionPeriod": backup_retention_period,
            "PreferredBackupWindow": preferred_backup_window,
            "Port": port,
            "MultiAZ": multi_az,
            "EngineVersion": engine_version,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "LicenseModel": license_model,
            "Iops": iops,
            "OptionGroupName": option_group_name,
            "CharacterSetName": character_set_name,
            "PubliclyAccessible": publicly_accessible,
            "Tags": tags,
            "DBClusterIdentifier": db_cluster_identifier,
            "StorageType": storage_type,
            "TdeCredentialArn": tde_credential_arn,
            "TdeCredentialPassword": tde_credential_password,
            "StorageEncrypted": storage_encrypted,
            "KmsKeyId": kms_key_id,
            "Domain": domain,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "MonitoringInterval": monitoring_interval,
            "MonitoringRoleArn": monitoring_role_arn,
            "DomainIAMRoleName": domain_iam_role_name,
            "PromotionTier": promotion_tier,
            "Timezone": timezone,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "EnablePerformanceInsights": enable_performance_insights,
            "PerformanceInsightsKMSKeyId": performance_insights_kms_key_id,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "DeletionProtection": deletion_protection,
        },
    )


async def delete(
    hub,
    ctx,
    db_instance_identifier: str,
    skip_final_snapshot: bool = None,
    final_db_snapshot_identifier: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The DeleteDBInstance action deletes a previously provisioned DB instance. When you delete a DB instance, all automated backups for that instance are deleted and can't be recovered. Manual DB snapshots of the DB instance to be deleted by DeleteDBInstance are not deleted.  If you request a final DB snapshot the status of the Amazon Neptune DB instance is deleting until the DB snapshot is created. The API action DescribeDBInstance is used to monitor the status of this operation. The action can't be canceled or reverted once submitted. Note that when a DB instance is in a failure state and has a status of failed, incompatible-restore, or incompatible-network, you can only delete it when the SkipFinalSnapshot parameter is set to true. You can't delete a DB instance if it is the only instance in the DB cluster, or if it has deletion protection enabled.

    Args:
        db_instance_identifier(str): The DB instance identifier for the DB instance to be deleted. This parameter isn't case-sensitive. Constraints:   Must match the name of an existing DB instance.  .
        skip_final_snapshot(bool, optional):  Determines whether a final DB snapshot is created before the DB instance is deleted. If true is specified, no DBSnapshot is created. If false is specified, a DB snapshot is created before the DB instance is deleted. Note that when a DB instance is in a failure state and has a status of 'failed', 'incompatible-restore', or 'incompatible-network', it can only be deleted when the SkipFinalSnapshot parameter is set to "true". Specify true when deleting a Read Replica.  The FinalDBSnapshotIdentifier parameter must be specified if SkipFinalSnapshot is false.  Default: false . Defaults to None.
        final_db_snapshot_identifier(str, optional):  The DBSnapshotIdentifier of the new DBSnapshot created when SkipFinalSnapshot is set to false.  Specifying this parameter and also setting the SkipFinalShapshot parameter to true results in an error.  Constraints:   Must be 1 to 255 letters or numbers.   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens   Cannot be specified when deleting a Read Replica.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.instance.delete(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.instance.delete db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="delete_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "SkipFinalSnapshot": skip_final_snapshot,
            "FinalDBSnapshotIdentifier": final_db_snapshot_identifier,
        },
    )


async def describe_all(
    hub,
    ctx,
    db_instance_identifier: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about provisioned instances, and supports pagination.  This operation can also return information for Amazon RDS instances and Amazon DocDB instances.

    Args:
        db_instance_identifier(str, optional): The user-supplied instance identifier. If this parameter is specified, information from only the specific DB instance is returned. This parameter isn't case-sensitive. Constraints:   If supplied, must match the identifier of an existing DBInstance.  . Defaults to None.
        filters(List, optional): A filter that specifies one or more DB instances to describe. Supported filters:    db-cluster-id - Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list will only include information about the DB instances associated with the DB clusters identified by these ARNs.    engine - Accepts an engine name (such as neptune), and restricts the results list to DB instances created by that engine.   For example, to invoke this API from the Amazon CLI and filter so that only Neptune DB instances are returned, you could use the following command:. Defaults to None.
        max_records(int, optional):  The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. Default: 100 Constraints: Minimum 20, maximum 100. Defaults to None.
        marker(str, optional):  An optional pagination token provided by a previous DescribeDBInstances request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.instance.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.instance.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="describe_db_instances",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    db_instance_identifier: str,
    allocated_storage: int = None,
    db_instance_class: str = None,
    db_subnet_group_name: str = None,
    db_security_groups: List = None,
    vpc_security_group_ids: List = None,
    apply_immediately: bool = None,
    master_user_password: str = None,
    db_parameter_group_name: str = None,
    backup_retention_period: int = None,
    preferred_backup_window: str = None,
    preferred_maintenance_window: str = None,
    multi_az: bool = None,
    engine_version: str = None,
    allow_major_version_upgrade: bool = None,
    auto_minor_version_upgrade: bool = None,
    license_model: str = None,
    iops: int = None,
    option_group_name: str = None,
    new_db_instance_identifier: str = None,
    storage_type: str = None,
    tde_credential_arn: str = None,
    tde_credential_password: str = None,
    ca_certificate_identifier: str = None,
    domain: str = None,
    copy_tags_to_snapshot: bool = None,
    monitoring_interval: int = None,
    db_port_number: int = None,
    publicly_accessible: bool = None,
    monitoring_role_arn: str = None,
    domain_iam_role_name: str = None,
    promotion_tier: int = None,
    enable_iam_database_authentication: bool = None,
    enable_performance_insights: bool = None,
    performance_insights_kms_key_id: str = None,
    cloudwatch_logs_export_configuration: Dict = None,
    deletion_protection: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies settings for a DB instance. You can change one or more database configuration parameters by specifying these parameters and the new values in the request. To learn what modifications you can make to your DB instance, call DescribeValidDBInstanceModifications before you call ModifyDBInstance.

    Args:
        db_instance_identifier(str): The DB instance identifier. This value is stored as a lowercase string. Constraints:   Must match the identifier of an existing DBInstance.  .
        allocated_storage(int, optional): Not supported by Neptune. Defaults to None.
        db_instance_class(str, optional): The new compute and memory capacity of the DB instance, for example, db.m4.large. Not all DB instance classes are available in all AWS Regions. If you modify the DB instance class, an outage occurs during the change. The change is applied during the next maintenance window, unless ApplyImmediately is specified as true for this request. Default: Uses existing setting. Defaults to None.
        db_subnet_group_name(str, optional): The new DB subnet group for the DB instance. You can use this parameter to move your DB instance to a different VPC. Changing the subnet group causes an outage during the change. The change is applied during the next maintenance window, unless you specify true for the ApplyImmediately parameter. Constraints: If supplied, must match the name of an existing DBSubnetGroup. Example: mySubnetGroup . Defaults to None.
        db_security_groups(List, optional): A list of DB security groups to authorize on this DB instance. Changing this setting doesn't result in an outage and the change is asynchronously applied as soon as possible. Constraints:   If supplied, must match existing DBSecurityGroups.  . Defaults to None.
        vpc_security_group_ids(List, optional): A list of EC2 VPC security groups to authorize on this DB instance. This change is asynchronously applied as soon as possible. Not applicable. The associated list of EC2 VPC security groups is managed by the DB cluster. For more information, see ModifyDBCluster. Constraints:   If supplied, must match existing VpcSecurityGroupIds.  . Defaults to None.
        apply_immediately(bool, optional): Specifies whether the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB instance.  If this parameter is set to false, changes to the DB instance are applied during the next maintenance window. Some parameter changes can cause an outage and are applied on the next call to RebootDBInstance, or the next failure reboot. Default: false . Defaults to None.
        master_user_password(str, optional): Not supported by Neptune. Defaults to None.
        db_parameter_group_name(str, optional): The name of the DB parameter group to apply to the DB instance. Changing this setting doesn't result in an outage. The parameter group name itself is changed immediately, but the actual parameter changes are not applied until you reboot the instance without failover. The db instance will NOT be rebooted automatically and the parameter changes will NOT be applied during the next maintenance window. Default: Uses existing setting Constraints: The DB parameter group must be in the same DB parameter group family as this DB instance. Defaults to None.
        backup_retention_period(int, optional): Not applicable. The retention period for automated backups is managed by the DB cluster. For more information, see ModifyDBCluster. Default: Uses existing setting. Defaults to None.
        preferred_backup_window(str, optional):  The daily time range during which automated backups are created if automated backups are enabled. Not applicable. The daily time range for creating automated backups is managed by the DB cluster. For more information, see ModifyDBCluster. Constraints:   Must be in the format hh24:mi-hh24:mi   Must be in Universal Time Coordinated (UTC)   Must not conflict with the preferred maintenance window   Must be at least 30 minutes  . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage. Changing this parameter doesn't result in an outage, except in the following situation, and the change is asynchronously applied as soon as possible. If there are pending actions that cause a reboot, and the maintenance window is changed to include the current time, then changing this parameter will cause a reboot of the DB instance. If moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure pending changes are applied. Default: Uses existing setting Format: ddd:hh24:mi-ddd:hh24:mi Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun Constraints: Must be at least 30 minutes. Defaults to None.
        multi_az(bool, optional): Specifies if the DB instance is a Multi-AZ deployment. Changing this parameter doesn't result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to true for this request. Defaults to None.
        engine_version(str, optional): The version number of the database engine to upgrade to. Currently, setting this parameter has no effect. To upgrade your database engine to the most recent release, use the ApplyPendingMaintenanceAction API. Defaults to None.
        allow_major_version_upgrade(bool, optional): Indicates that major version upgrades are allowed. Changing this parameter doesn't result in an outage and the change is asynchronously applied as soon as possible. Defaults to None.
        auto_minor_version_upgrade(bool, optional):  Indicates that minor version upgrades are applied automatically to the DB instance during the maintenance window. Changing this parameter doesn't result in an outage except in the following case and the change is asynchronously applied as soon as possible. An outage will result if this parameter is set to true during the maintenance window, and a newer minor version is available, and Neptune has enabled auto patching for that engine version. Defaults to None.
        license_model(str, optional): Not supported by Neptune. Defaults to None.
        iops(int, optional): The new Provisioned IOPS (I/O operations per second) value for the instance. Changing this setting doesn't result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to true for this request. Default: Uses existing setting. Defaults to None.
        option_group_name(str, optional):  (Not supported by Neptune) . Defaults to None.
        new_db_instance_identifier(str, optional):  The new DB instance identifier for the DB instance when renaming a DB instance. When you change the DB instance identifier, an instance reboot will occur immediately if you set Apply Immediately to true, or will occur during the next maintenance window if Apply Immediately to false. This value is stored as a lowercase string. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens.   The first character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.   Example: mydbinstance . Defaults to None.
        storage_type(str, optional): Not supported. Defaults to None.
        tde_credential_arn(str, optional): The ARN from the key store with which to associate the instance for TDE encryption. Defaults to None.
        tde_credential_password(str, optional): The password for the given ARN from the key store in order to access the device. Defaults to None.
        ca_certificate_identifier(str, optional): Indicates the certificate that needs to be associated with the instance. Defaults to None.
        domain(str, optional): Not supported. Defaults to None.
        copy_tags_to_snapshot(bool, optional): True to copy all tags from the DB instance to snapshots of the DB instance, and otherwise false. The default is false. Defaults to None.
        monitoring_interval(int, optional): The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB instance. To disable collecting Enhanced Monitoring metrics, specify 0. The default is 0. If MonitoringRoleArn is specified, then you must also set MonitoringInterval to a value other than 0. Valid Values: 0, 1, 5, 10, 15, 30, 60 . Defaults to None.
        db_port_number(int, optional): The port number on which the database accepts connections. The value of the DBPortNumber parameter must not match any of the port values specified for options in the option group for the DB instance. Your database will restart when you change the DBPortNumber value regardless of the value of the ApplyImmediately parameter.  Default: 8182 . Defaults to None.
        publicly_accessible(bool, optional): This flag should no longer be used. Defaults to None.
        monitoring_role_arn(str, optional): The ARN for the IAM role that permits Neptune to send enhanced monitoring metrics to Amazon CloudWatch Logs. For example, arn:aws:iam:123456789012:role/emaccess. If MonitoringInterval is set to a value other than 0, then you must supply a MonitoringRoleArn value. Defaults to None.
        domain_iam_role_name(str, optional): Not supported. Defaults to None.
        promotion_tier(int, optional): A value that specifies the order in which a Read Replica is promoted to the primary instance after a failure of the existing primary instance. Default: 1 Valid Values: 0 - 15. Defaults to None.
        enable_iam_database_authentication(bool, optional): True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false. You can enable IAM database authentication for the following database engines Not applicable. Mapping Amazon IAM accounts to database accounts is managed by the DB cluster. For more information, see ModifyDBCluster. Default: false . Defaults to None.
        enable_performance_insights(bool, optional):  (Not supported by Neptune) . Defaults to None.
        performance_insights_kms_key_id(str, optional):  (Not supported by Neptune) . Defaults to None.
        cloudwatch_logs_export_configuration(Dict, optional): The configuration setting for the log types to be enabled for export to CloudWatch Logs for a specific DB instance or DB cluster. Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB instance has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. See Deleting a DB Instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.instance.modify(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.instance.modify db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="modify_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "AllocatedStorage": allocated_storage,
            "DBInstanceClass": db_instance_class,
            "DBSubnetGroupName": db_subnet_group_name,
            "DBSecurityGroups": db_security_groups,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "ApplyImmediately": apply_immediately,
            "MasterUserPassword": master_user_password,
            "DBParameterGroupName": db_parameter_group_name,
            "BackupRetentionPeriod": backup_retention_period,
            "PreferredBackupWindow": preferred_backup_window,
            "PreferredMaintenanceWindow": preferred_maintenance_window,
            "MultiAZ": multi_az,
            "EngineVersion": engine_version,
            "AllowMajorVersionUpgrade": allow_major_version_upgrade,
            "AutoMinorVersionUpgrade": auto_minor_version_upgrade,
            "LicenseModel": license_model,
            "Iops": iops,
            "OptionGroupName": option_group_name,
            "NewDBInstanceIdentifier": new_db_instance_identifier,
            "StorageType": storage_type,
            "TdeCredentialArn": tde_credential_arn,
            "TdeCredentialPassword": tde_credential_password,
            "CACertificateIdentifier": ca_certificate_identifier,
            "Domain": domain,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
            "MonitoringInterval": monitoring_interval,
            "DBPortNumber": db_port_number,
            "PubliclyAccessible": publicly_accessible,
            "MonitoringRoleArn": monitoring_role_arn,
            "DomainIAMRoleName": domain_iam_role_name,
            "PromotionTier": promotion_tier,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "EnablePerformanceInsights": enable_performance_insights,
            "PerformanceInsightsKMSKeyId": performance_insights_kms_key_id,
            "CloudwatchLogsExportConfiguration": cloudwatch_logs_export_configuration,
            "DeletionProtection": deletion_protection,
        },
    )


async def reboot(
    hub, ctx, db_instance_identifier: str, force_failover: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    You might need to reboot your DB instance, usually for maintenance reasons. For example, if you make certain modifications, or if you change the DB parameter group associated with the DB instance, you must reboot the instance for the changes to take effect. Rebooting a DB instance restarts the database engine service. Rebooting a DB instance results in a momentary outage, during which the DB instance status is set to rebooting.

    Args:
        db_instance_identifier(str): The DB instance identifier. This parameter is stored as a lowercase string. Constraints:   Must match the identifier of an existing DBInstance.  .
        force_failover(bool, optional):  When true, the reboot is conducted through a MultiAZ failover. Constraint: You can't specify true if the instance is not configured for MultiAZ. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.instance.reboot(ctx, db_instance_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.instance.reboot db_instance_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="reboot_db_instance",
        op_kwargs={
            "DBInstanceIdentifier": db_instance_identifier,
            "ForceFailover": force_failover,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "subscription_filter"


async def delete(hub, ctx, log_group_name: str, filter_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified subscription filter.

    Args:
        log_group_name(str): The name of the log group.
        filter_name(str): The name of the subscription filter.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.subscription_filter_.delete(
                ctx, log_group_name=value, filter_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.subscription_filter.delete log_group_name=value, filter_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="delete_subscription_filter",
        op_kwargs={"logGroupName": log_group_name, "filterName": filter_name},
    )


async def describe_all(
    hub,
    ctx,
    log_group_name: str,
    filter_name_prefix: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the subscription filters for the specified log group. You can list all the subscription filters or filter the results by prefix. The results are ASCII-sorted by filter name.

    Args:
        log_group_name(str): The name of the log group.
        filter_name_prefix(str, optional): The prefix to match. If you don't specify a value, no prefix filter is applied. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        limit(int, optional): The maximum number of items returned. If you don't specify a value, the default is up to 50 items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.subscription_filter_.describe_all(
                ctx, log_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.subscription_filter.describe_all log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="describe_subscription_filters",
        op_kwargs={
            "logGroupName": log_group_name,
            "filterNamePrefix": filter_name_prefix,
            "nextToken": next_token,
            "limit": limit,
        },
    )


async def put(
    hub,
    ctx,
    log_group_name: str,
    filter_name: str,
    filter_pattern: str,
    destination_arn: str,
    role_arn: str = None,
    distribution: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Creates or updates a subscription filter and associates it with the specified log group. Subscription filters allow you to subscribe to a real-time stream of log events ingested through PutLogEvents and have them delivered to a specific destination. When log events are sent to the receiving service, they are Base64 encoded and compressed with the gzip format. The following destinations are supported for subscription filters:   An Amazon Kinesis stream belonging to the same account as the subscription filter, for same-account delivery.   A logical destination that belongs to a different account, for cross-account delivery.   An Amazon Kinesis Firehose delivery stream that belongs to the same account as the subscription filter, for same-account delivery.   An AWS Lambda function that belongs to the same account as the subscription filter, for same-account delivery.   Each log group can have up to two subscription filters associated with it. If you are updating an existing filter, you must specify the correct name in filterName.  To perform a PutSubscriptionFilter operation, you must also have the iam:PassRole permission.

    Args:
        log_group_name(str): The name of the log group.
        filter_name(str): A name for the subscription filter. If you are updating an existing filter, you must specify the correct name in filterName. To find the name of the filter currently associated with a log group, use DescribeSubscriptionFilters.
        filter_pattern(str): A filter pattern for subscribing to a filtered stream of log events.
        destination_arn(str): The ARN of the destination to deliver matching log events to. Currently, the supported destinations are:   An Amazon Kinesis stream belonging to the same account as the subscription filter, for same-account delivery.   A logical destination (specified using an ARN) belonging to a different account, for cross-account delivery. If you are setting up a cross-account subscription, the destination must have an IAM policy associated with it that allows the sender to send logs to the destination. For more information, see PutDestinationPolicy.   An Amazon Kinesis Firehose delivery stream belonging to the same account as the subscription filter, for same-account delivery.   An AWS Lambda function belonging to the same account as the subscription filter, for same-account delivery.  .
        role_arn(str, optional): The ARN of an IAM role that grants CloudWatch Logs permissions to deliver ingested log events to the destination stream. You don't need to provide the ARN when you are working with a logical destination for cross-account delivery. Defaults to None.
        distribution(str, optional): The method used to distribute log data to the destination. By default, log data is grouped by log stream, but the grouping can be set to random for a more even distribution. This property is only applicable when the destination is an Amazon Kinesis stream. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.subscription_filter_.put(
                ctx,
                log_group_name=value,
                filter_name=value,
                filter_pattern=value,
                destination_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.subscription_filter.put log_group_name=value, filter_name=value, filter_pattern=value, destination_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="put_subscription_filter",
        op_kwargs={
            "logGroupName": log_group_name,
            "filterName": filter_name,
            "filterPattern": filter_pattern,
            "destinationArn": destination_arn,
            "roleArn": role_arn,
            "distribution": distribution,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    document_version: str = None,
    instance_id: str = None,
    parameters: Dict = None,
    targets: List = None,
    schedule_expression: str = None,
    output_location: Dict = None,
    association_name: str = None,
    automation_target_parameter_name: str = None,
    max_errors: str = None,
    max_concurrency: str = None,
    compliance_severity: str = None,
    sync_compliance: str = None,
    apply_only_at_cron_interval: bool = None,
    calendar_names: List = None,
    target_locations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    A State Manager association defines the state that you want to maintain on your instances. For example, an association can specify that anti-virus software must be installed and running on your instances, or that certain ports must be closed. For static targets, the association specifies a schedule for when the configuration is reapplied. For dynamic targets, such as an Amazon Web Services resource group or an Amazon Web Services autoscaling group, State Manager, a capability of Amazon Web Services Systems Manager applies the configuration when new instances are added to the group. The association also specifies actions to take when applying the configuration. For example, an association for anti-virus software might run once a day. If the software isn't installed, then State Manager installs it. If the software is installed, but the service isn't running, then the association might instruct State Manager to start the service.

    Args:
        name(str): The name of the SSM Command document or Automation runbook that contains the configuration information for the instance. You can specify Amazon Web Services-predefined documents, documents you created, or a document that is shared with you from another account. For Systems Manager documents (SSM documents) that are shared with you from other accounts, you must specify the complete SSM document ARN, in the following format:  arn:partition:ssm:region:account-id:document/document-name   For example:  arn:aws:ssm:us-east-2:12345678912:document/My-Shared-Document  For Amazon Web Services-predefined documents and SSM documents you created in your account, you only need to specify the document name. For example, AWS-ApplyPatchBaseline or My-Document.
        document_version(str, optional): The document version you want to associate with the target(s). Can be a specific version or the default version. Defaults to None.
        instance_id(str, optional): The instance ID.   InstanceId has been deprecated. To specify an instance ID for an association, use the Targets parameter. Requests that include the parameter InstanceID with Systems Manager documents (SSM documents) that use schema version 2.0 or later will fail. In addition, if you use the parameter InstanceId, you can't use the parameters AssociationName, DocumentVersion, MaxErrors, MaxConcurrency, OutputLocation, or ScheduleExpression. To use these parameters, you must use the Targets parameter. . Defaults to None.
        parameters(Dict, optional): The parameters for the runtime configuration of the document. Defaults to None.
        targets(List, optional): The targets for the association. You can target instances by using tags, Amazon Web Services resource groups, all instances in an account, or individual instance IDs. For more information about choosing targets for an association, see Using targets and rate controls with State Manager associations in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        schedule_expression(str, optional): A cron expression when the association will be applied to the target(s). Defaults to None.
        output_location(Dict, optional): An Amazon Simple Storage Service (Amazon S3) bucket where you want to store the output details of the request. Defaults to None.
        association_name(str, optional): Specify a descriptive name for the association. Defaults to None.
        automation_target_parameter_name(str, optional): Specify the target for the association. This target is required for associations that use an Automation runbook and target resources by using rate controls. Automation is a capability of Amazon Web Services Systems Manager. Defaults to None.
        max_errors(str, optional): The number of errors that are allowed before the system stops sending requests to run the association on additional targets. You can specify either an absolute number of errors, for example 10, or a percentage of the target set, for example 10%. If you specify 3, for example, the system stops sending requests when the fourth error is received. If you specify 0, then the system stops sending requests after the first error is returned. If you run an association on 50 instances and set MaxError to 10%, then the system stops sending the request when the sixth error is received. Executions that are already running an association when MaxErrors is reached are allowed to complete, but some of these executions may fail as well. If you need to ensure that there won't be more than max-errors failed executions, set MaxConcurrency to 1 so that executions proceed one at a time. Defaults to None.
        max_concurrency(str, optional): The maximum number of targets allowed to run the association at the same time. You can specify a number, for example 10, or a percentage of the target set, for example 10%. The default value is 100%, which means all targets run the association at the same time. If a new instance starts and attempts to run an association while Systems Manager is running MaxConcurrency associations, the association is allowed to run. During the next association interval, the new instance will process its association within the limit specified for MaxConcurrency. Defaults to None.
        compliance_severity(str, optional): The severity level to assign to the association. Defaults to None.
        sync_compliance(str, optional): The mode for generating association compliance. You can specify AUTO or MANUAL. In AUTO mode, the system uses the status of the association execution to determine the compliance status. If the association execution runs successfully, then the association is COMPLIANT. If the association execution doesn't run successfully, the association is NON-COMPLIANT. In MANUAL mode, you must specify the AssociationId as a parameter for the PutComplianceItems API operation. In this case, compliance data isn't managed by State Manager. It is managed by your direct call to the PutComplianceItems API operation. By default, all associations use AUTO mode. Defaults to None.
        apply_only_at_cron_interval(bool, optional): By default, when you create a new association, the system runs it immediately after it is created and then according to the schedule you specified. Specify this option if you don't want an association to run immediately after you create it. This parameter isn't supported for rate expressions. Defaults to None.
        calendar_names(List, optional): The names or Amazon Resource Names (ARNs) of the Change Calendar type documents you want to gate your associations under. The associations only run when that change calendar is open. For more information, see Amazon Web Services Systems Manager Change Calendar. Defaults to None.
        target_locations(List, optional): A location is a combination of Regions and accounts where you want to run the association. Use this action to create an association in multiple Regions and multiple accounts. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="create_association",
        op_kwargs={
            "Name": name,
            "DocumentVersion": document_version,
            "InstanceId": instance_id,
            "Parameters": parameters,
            "Targets": targets,
            "ScheduleExpression": schedule_expression,
            "OutputLocation": output_location,
            "AssociationName": association_name,
            "AutomationTargetParameterName": automation_target_parameter_name,
            "MaxErrors": max_errors,
            "MaxConcurrency": max_concurrency,
            "ComplianceSeverity": compliance_severity,
            "SyncCompliance": sync_compliance,
            "ApplyOnlyAtCronInterval": apply_only_at_cron_interval,
            "CalendarNames": calendar_names,
            "TargetLocations": target_locations,
        },
    )


async def delete(
    hub, ctx, name: str = None, instance_id: str = None, association_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified Amazon Web Services Systems Manager document (SSM document) from the specified instance. When you disassociate a document from an instance, it doesn't change the configuration of the instance. To change the configuration state of an instance after you disassociate a document, you must create a new document with the desired configuration and associate it with the instance.

    Args:
        name(str, optional): The name of the SSM document. Defaults to None.
        instance_id(str, optional): The ID of the instance. Defaults to None.
        association_id(str, optional): The association ID that you want to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="delete_association",
        op_kwargs={
            "Name": name,
            "InstanceId": instance_id,
            "AssociationId": association_id,
        },
    )


async def describe(
    hub,
    ctx,
    name: str = None,
    instance_id: str = None,
    association_id: str = None,
    association_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the association for the specified target or instance. If you created the association by using the Targets parameter, then you must retrieve the association by using the association ID. If you created the association by specifying an instance ID and an Amazon Web Services Systems Manager document (SSM document), then you retrieve the association by specifying the document name and the instance ID.

    Args:
        name(str, optional): The name of the SSM document. Defaults to None.
        instance_id(str, optional): The instance ID. Defaults to None.
        association_id(str, optional): The association ID for which you want information. Defaults to None.
        association_version(str, optional): Specify the association version to retrieve. To view the latest version, either specify $LATEST for this parameter, or omit this parameter. To view a list of all associations for an instance, use ListAssociations. To get a list of versions for a specific association, use ListAssociationVersions. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_association",
        op_kwargs={
            "Name": name,
            "InstanceId": instance_id,
            "AssociationId": association_id,
            "AssociationVersion": association_version,
        },
    )


async def list_all(
    hub,
    ctx,
    association_filter_list: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all State Manager associations in the current account and Region. You can limit the results to a specific State Manager association document or instance by specifying a filter. State Manager is a capability of Amazon Web Services Systems Manager.

    Args:
        association_filter_list(List, optional): One or more filters. Use a filter to return a more specific list of results.  Filtering associations using the InstanceID attribute only returns legacy associations created using the InstanceID attribute. Associations targeting the instance that are part of the Target Attributes ResourceGroup or Tags aren't returned. . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_associations",
        op_kwargs={
            "AssociationFilterList": association_filter_list,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    association_id: str,
    parameters: Dict = None,
    document_version: str = None,
    schedule_expression: str = None,
    output_location: Dict = None,
    name: str = None,
    targets: List = None,
    association_name: str = None,
    association_version: str = None,
    automation_target_parameter_name: str = None,
    max_errors: str = None,
    max_concurrency: str = None,
    compliance_severity: str = None,
    sync_compliance: str = None,
    apply_only_at_cron_interval: bool = None,
    calendar_names: List = None,
    target_locations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an association. You can update the association name and version, the document version, schedule, parameters, and Amazon Simple Storage Service (Amazon S3) output.  In order to call this API operation, your Identity and Access Management (IAM) user account, group, or role must be configured with permission to call the DescribeAssociation API operation. If you don't have permission to call DescribeAssociation, then you receive the following error: An error occurred (AccessDeniedException) when calling the UpdateAssociation operation: User: <user_arn> isn't authorized to perform: ssm:DescribeAssociation on resource: <resource_arn>   When you update an association, the association immediately runs against the specified targets.

    Args:
        association_id(str): The ID of the association you want to update. .
        parameters(Dict, optional): The parameters you want to update for the association. If you create a parameter using Parameter Store, a capability of Amazon Web Services Systems Manager, you can reference the parameter using {{ssm:parameter-name}}. Defaults to None.
        document_version(str, optional): The document version you want update for the association. . Defaults to None.
        schedule_expression(str, optional): The cron expression used to schedule the association that you want to update. Defaults to None.
        output_location(Dict, optional): An S3 bucket where you want to store the results of this request. Defaults to None.
        name(str, optional): The name of the SSM Command document or Automation runbook that contains the configuration information for the instance. You can specify Amazon Web Services-predefined documents, documents you created, or a document that is shared with you from another account. For Systems Manager document (SSM document) that are shared with you from other accounts, you must specify the complete SSM document ARN, in the following format:  arn:aws:ssm:region:account-id:document/document-name   For example:  arn:aws:ssm:us-east-2:12345678912:document/My-Shared-Document  For Amazon Web Services-predefined documents and SSM documents you created in your account, you only need to specify the document name. For example, AWS-ApplyPatchBaseline or My-Document. Defaults to None.
        targets(List, optional): The targets of the association. Defaults to None.
        association_name(str, optional): The name of the association that you want to update. Defaults to None.
        association_version(str, optional): This parameter is provided for concurrency control purposes. You must specify the latest association version in the service. If you want to ensure that this request succeeds, either specify $LATEST, or omit this parameter. Defaults to None.
        automation_target_parameter_name(str, optional): Specify the target for the association. This target is required for associations that use an Automation runbook and target resources by using rate controls. Automation is a capability of Amazon Web Services Systems Manager. Defaults to None.
        max_errors(str, optional): The number of errors that are allowed before the system stops sending requests to run the association on additional targets. You can specify either an absolute number of errors, for example 10, or a percentage of the target set, for example 10%. If you specify 3, for example, the system stops sending requests when the fourth error is received. If you specify 0, then the system stops sending requests after the first error is returned. If you run an association on 50 instances and set MaxError to 10%, then the system stops sending the request when the sixth error is received. Executions that are already running an association when MaxErrors is reached are allowed to complete, but some of these executions may fail as well. If you need to ensure that there won't be more than max-errors failed executions, set MaxConcurrency to 1 so that executions proceed one at a time. Defaults to None.
        max_concurrency(str, optional): The maximum number of targets allowed to run the association at the same time. You can specify a number, for example 10, or a percentage of the target set, for example 10%. The default value is 100%, which means all targets run the association at the same time. If a new instance starts and attempts to run an association while Systems Manager is running MaxConcurrency associations, the association is allowed to run. During the next association interval, the new instance will process its association within the limit specified for MaxConcurrency. Defaults to None.
        compliance_severity(str, optional): The severity level to assign to the association. Defaults to None.
        sync_compliance(str, optional): The mode for generating association compliance. You can specify AUTO or MANUAL. In AUTO mode, the system uses the status of the association execution to determine the compliance status. If the association execution runs successfully, then the association is COMPLIANT. If the association execution doesn't run successfully, the association is NON-COMPLIANT. In MANUAL mode, you must specify the AssociationId as a parameter for the PutComplianceItems API operation. In this case, compliance data isn't managed by State Manager, a capability of Amazon Web Services Systems Manager. It is managed by your direct call to the PutComplianceItems API operation. By default, all associations use AUTO mode. Defaults to None.
        apply_only_at_cron_interval(bool, optional): By default, when you update an association, the system runs it immediately after it is updated and then according to the schedule you specified. Specify this option if you don't want an association to run immediately after you update it. This parameter isn't supported for rate expressions. Also, if you specified this option when you created the association, you can reset it. To do so, specify the no-apply-only-at-cron-interval parameter when you update the association from the command line. This parameter forces the association to run immediately after updating it and according to the interval specified. Defaults to None.
        calendar_names(List, optional): The names or Amazon Resource Names (ARNs) of the Change Calendar type documents you want to gate your associations under. The associations only run when that change calendar is open. For more information, see Amazon Web Services Systems Manager Change Calendar. Defaults to None.
        target_locations(List, optional): A location is a combination of Regions and accounts where you want to run the association. Use this action to update an association in multiple Regions and multiple accounts. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.association.init.update(ctx, association_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.association.init.update association_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="update_association",
        op_kwargs={
            "AssociationId": association_id,
            "Parameters": parameters,
            "DocumentVersion": document_version,
            "ScheduleExpression": schedule_expression,
            "OutputLocation": output_location,
            "Name": name,
            "Targets": targets,
            "AssociationName": association_name,
            "AssociationVersion": association_version,
            "AutomationTargetParameterName": automation_target_parameter_name,
            "MaxErrors": max_errors,
            "MaxConcurrency": max_concurrency,
            "ComplianceSeverity": compliance_severity,
            "SyncCompliance": sync_compliance,
            "ApplyOnlyAtCronInterval": apply_only_at_cron_interval,
            "CalendarNames": calendar_names,
            "TargetLocations": target_locations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, flow_arn: str, outputs: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds outputs to an existing flow. You can create up to 50 outputs per flow.

    Args:
        flow_arn(str): The flow that you want to add outputs to.
        outputs(List): A list of outputs that you want to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.output.add(ctx, flow_arn=value, outputs=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.output.add flow_arn=value, outputs=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="add_flow_outputs",
        op_kwargs={"FlowArn": flow_arn, "Outputs": outputs},
    )


async def remove(hub, ctx, flow_arn: str, output_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes an output from an existing flow. This request can be made only on an output that does not have an entitlement associated with it. If the output has an entitlement, you must revoke the entitlement instead. When an entitlement is revoked from a flow, the service automatically removes the associated output.

    Args:
        flow_arn(str): The flow that you want to remove an output from.
        output_arn(str): The ARN of the output that you want to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.output.remove(
                ctx, flow_arn=value, output_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.output.remove flow_arn=value, output_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="remove_flow_output",
        op_kwargs={"FlowArn": flow_arn, "OutputArn": output_arn},
    )


async def update(
    hub,
    ctx,
    flow_arn: str,
    output_arn: str,
    cidr_allow_list: List = None,
    description: str = None,
    destination: str = None,
    encryption: Dict = None,
    max_latency: int = None,
    media_stream_output_configurations: List = None,
    min_latency: int = None,
    port: int = None,
    protocol: str = None,
    remote_id: str = None,
    smoothing_latency: int = None,
    stream_id: str = None,
    vpc_interface_attachment: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing flow output.

    Args:
        cidr_allow_list(List, optional): The range of IP addresses that should be allowed to initiate output requests to this flow. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16. Defaults to None.
        description(str, optional): A description of the output. This description appears only on the AWS Elemental MediaConnect console and will not be seen by the end user. Defaults to None.
        destination(str, optional): The IP address where you want to send the output. Defaults to None.
        encryption(Dict, optional): The type of key used for the encryption. If no keyType is provided, the service will use the default setting (static-key). Defaults to None.
        flow_arn(str): The flow that is associated with the output that you want to update.
        max_latency(int, optional): The maximum latency in milliseconds for Zixi-based streams. Defaults to None.
        media_stream_output_configurations(List, optional): The media streams that are associated with the output, and the parameters for those associations. Defaults to None.
        min_latency(int, optional): The minimum latency in milliseconds for SRT-based streams. In streams that use the SRT protocol, this value that you set on your MediaConnect source or output represents the minimal potential latency of that connection. The latency of the stream is set to the highest number between the sender’s minimum latency and the receiver’s minimum latency. Defaults to None.
        output_arn(str): The ARN of the output that you want to update.
        port(int, optional): The port to use when content is distributed to this output. Defaults to None.
        protocol(str, optional): The protocol to use for the output. Defaults to None.
        remote_id(str, optional): The remote ID for the Zixi-pull stream. Defaults to None.
        smoothing_latency(int, optional): The smoothing latency in milliseconds for RIST, RTP, and RTP-FEC streams. Defaults to None.
        stream_id(str, optional): The stream ID that you want to use for this transport. This parameter applies only to Zixi-based streams. Defaults to None.
        vpc_interface_attachment(Dict, optional): The name of the VPC interface attachment to use for this output. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediaconnect.flow.output.update(
                ctx, flow_arn=value, output_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediaconnect.flow.output.update flow_arn=value, output_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediaconnect",
        operation="update_flow_output",
        op_kwargs={
            "CidrAllowList": cidr_allow_list,
            "Description": description,
            "Destination": destination,
            "Encryption": encryption,
            "FlowArn": flow_arn,
            "MaxLatency": max_latency,
            "MediaStreamOutputConfigurations": media_stream_output_configurations,
            "MinLatency": min_latency,
            "OutputArn": output_arn,
            "Port": port,
            "Protocol": protocol,
            "RemoteId": remote_id,
            "SmoothingLatency": smoothing_latency,
            "StreamId": stream_id,
            "VpcInterfaceAttachment": vpc_interface_attachment,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    author: str,
    description: str,
    name: str,
    home_page_url: str = None,
    labels: List = None,
    license_body: str = None,
    license_url: str = None,
    readme_body: str = None,
    readme_url: str = None,
    semantic_version: str = None,
    source_code_archive_url: str = None,
    source_code_url: str = None,
    spdx_license_id: str = None,
    template_body: str = None,
    template_url: str = None,
) -> Dict:
    r"""
        **Autogenerated function**

        Creates an application, optionally including an AWS SAM file to create the first application version in the same call.

        Args:
            author(str): The name of the author publishing the app.Minimum length=1. Maximum length=127.Pattern "^[a-z0-9](([a-z0-9]|-(?!-))*[a-z0-9])?$";.
            description(str): The description of the application.Minimum length=1. Maximum length=256.
            home_page_url(str, optional): A URL with more information about the application, for example the location of your GitHub repository for the application. Defaults to None.
            labels(List, optional): Labels to improve discovery of apps in search results.Minimum length=1. Maximum length=127. Maximum number of labels: 10Pattern: "^[a-zA-Z0-9+\\-_:\\/@]+$";. Defaults to None.
            license_body(str, optional): A local text file that contains the license of the app that matches the spdxLicenseID value of your application.
     The file has the format file://<path>/<filename>.Maximum size 5 MBYou can specify only one of licenseBody and licenseUrl; otherwise, an error results. Defaults to None.
            license_url(str, optional): A link to the S3 object that contains the license of the app that matches the spdxLicenseID value of your application.Maximum size 5 MBYou can specify only one of licenseBody and licenseUrl; otherwise, an error results. Defaults to None.
            name(str): The name of the application that you want to publish.Minimum length=1. Maximum length=140Pattern: "[a-zA-Z0-9\\-]+";.
            readme_body(str, optional): A local text readme file in Markdown language that contains a more detailed description of the application and how it works.
     The file has the format file://<path>/<filename>.Maximum size 5 MBYou can specify only one of readmeBody and readmeUrl; otherwise, an error results. Defaults to None.
            readme_url(str, optional): A link to the S3 object in Markdown language that contains a more detailed description of the application and how it works.Maximum size 5 MBYou can specify only one of readmeBody and readmeUrl; otherwise, an error results. Defaults to None.
            semantic_version(str, optional): The semantic version of the application:
    https://semver.org/
    . Defaults to None.
            source_code_archive_url(str, optional): A link to the S3 object that contains the ZIP archive of the source code for this version of your application.Maximum size 50 MB. Defaults to None.
            source_code_url(str, optional): A link to a public repository for the source code of your application, for example the URL of a specific GitHub commit. Defaults to None.
            spdx_license_id(str, optional): A valid identifier from https://spdx.org/licenses/. Defaults to None.
            template_body(str, optional): The local raw packaged AWS SAM template file of your application.
     The file has the format file://<path>/<filename>.You can specify only one of templateBody and templateUrl; otherwise an error results. Defaults to None.
            template_url(str, optional): A link to the S3 object containing the packaged AWS SAM template of your application.You can specify only one of templateBody and templateUrl; otherwise an error results. Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.serverlessrepo.application.init.create(
                    ctx, author=value, description=value, name=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.serverlessrepo.application.init.create author=value, description=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="create_application",
        op_kwargs={
            "Author": author,
            "Description": description,
            "HomePageUrl": home_page_url,
            "Labels": labels,
            "LicenseBody": license_body,
            "LicenseUrl": license_url,
            "Name": name,
            "ReadmeBody": readme_body,
            "ReadmeUrl": readme_url,
            "SemanticVersion": semantic_version,
            "SourceCodeArchiveUrl": source_code_archive_url,
            "SourceCodeUrl": source_code_url,
            "SpdxLicenseId": spdx_license_id,
            "TemplateBody": template_body,
            "TemplateUrl": template_url,
        },
    )


async def delete(hub, ctx, application_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified application.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.init.delete(
                ctx, application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.init.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="delete_application",
        op_kwargs={"ApplicationId": application_id},
    )


async def get(hub, ctx, application_id: str, semantic_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the specified application.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        semantic_version(str, optional): The semantic version of the application to get. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.init.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.init.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="get_application",
        op_kwargs={
            "ApplicationId": application_id,
            "SemanticVersion": semantic_version,
        },
    )


async def list_all(hub, ctx, max_items: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists applications owned by the requester.

    Args:
        max_items(int, optional): The total number of items to return. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="list_applications",
        op_kwargs={"MaxItems": max_items, "NextToken": next_token},
    )


async def unshare(hub, ctx, application_id: str, organization_id: str) -> None:
    r"""
    **Autogenerated function**

    Unshares an application from an AWS Organization.This operation can be called only from the organization's master account.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        organization_id(str): The AWS Organization ID to unshare the application from.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.init.unshare(
                ctx, application_id=value, organization_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.init.unshare application_id=value, organization_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="unshare_application",
        op_kwargs={"ApplicationId": application_id, "OrganizationId": organization_id},
    )


async def update(
    hub,
    ctx,
    application_id: str,
    author: str = None,
    description: str = None,
    home_page_url: str = None,
    labels: List = None,
    readme_body: str = None,
    readme_url: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified application.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        author(str, optional): The name of the author publishing the app.Minimum length=1. Maximum length=127.Pattern "^[a-z0-9](([a-z0-9]|-(?!-))*[a-z0-9])?$";. Defaults to None.
        description(str, optional): The description of the application.Minimum length=1. Maximum length=256. Defaults to None.
        home_page_url(str, optional): A URL with more information about the application, for example the location of your GitHub repository for the application. Defaults to None.
        labels(List, optional): Labels to improve discovery of apps in search results.Minimum length=1. Maximum length=127. Maximum number of labels: 10Pattern: "^[a-zA-Z0-9+\\-_:\\/@]+$";. Defaults to None.
        readme_body(str, optional): A text readme file in Markdown language that contains a more detailed description of the application and how it works.Maximum size 5 MB. Defaults to None.
        readme_url(str, optional): A link to the readme file in Markdown language that contains a more detailed description of the application and how it works.Maximum size 5 MB. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.init.update(
                ctx, application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.init.update application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="update_application",
        op_kwargs={
            "ApplicationId": application_id,
            "Author": author,
            "Description": description,
            "HomePageUrl": home_page_url,
            "Labels": labels,
            "ReadmeBody": readme_body,
            "ReadmeUrl": readme_url,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get(hub, ctx, identity_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the configuration settings of an identity pool.This API can only be called with developer credentials. You cannot call this API with the temporary user credentials provided by Cognito Identity.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. This is the ID of the pool for which to return a configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.identity.pool.configuration.get(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.identity.pool.configuration.get identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="get_identity_pool_configuration",
        op_kwargs={"IdentityPoolId": identity_pool_id},
    )


async def set_(
    hub,
    ctx,
    identity_pool_id: str,
    push_sync: Dict = None,
    cognito_streams: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the necessary configuration for push sync.This API can only be called with developer credentials. You cannot call this API with the temporary user credentials provided by Cognito Identity.

    Args:
        identity_pool_id(str): A name-spaced GUID (for example, us-east-1:23EC4050-6AEA-7089-A2DD-08002EXAMPLE) created by Amazon Cognito. This is the ID of the pool to modify.
        push_sync(Dict, optional): Options to apply to this identity pool for push synchronization. Defaults to None.
        cognito_streams(Dict, optional): Options to apply to this identity pool for Amazon Cognito streams. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_sync.identity.pool.configuration.set(
                ctx, identity_pool_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_sync.identity.pool.configuration.set identity_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-sync",
        operation="set_identity_pool_configuration",
        op_kwargs={
            "IdentityPoolId": identity_pool_id,
            "PushSync": push_sync,
            "CognitoStreams": cognito_streams,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, project_arn: str, expires_in_seconds: int) -> Dict:
    r"""
    **Autogenerated function**

    Creates a signed, short-term URL that can be passed to a Selenium RemoteWebDriver constructor.

    Args:
        project_arn(str): ARN (from CreateTestGridProject or ListTestGridProjects) to associate with the short-term URL. .
        expires_in_seconds(int): Lifetime, in seconds, of the URL.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.test.grid.url.create(
                ctx, project_arn=value, expires_in_seconds=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.test.grid.url.create project_arn=value, expires_in_seconds=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_test_grid_url",
        op_kwargs={"projectArn": project_arn, "expiresInSeconds": expires_in_seconds},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a saved resource, including the last time it was backed up, its Amazon Resource Name (ARN), and the AWS service type of the saved resource.

    Args:
        resource_arn(str): An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the resource type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.protected_resource.describe(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.protected_resource.describe resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="describe_protected_resource",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of resources successfully backed up by AWS Backup, including the time the resource was saved, an Amazon Resource Name (ARN) of the resource, and a resource type.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.protected_resource.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.protected_resource.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_protected_resources",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "filter"


async def create(
    hub,
    ctx,
    vocabulary_filter_name: str,
    language_code: str,
    words: List = None,
    vocabulary_filter_file_uri: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new vocabulary filter that you can use to filter words, such as profane words, from the output of a transcription job.

    Args:
        vocabulary_filter_name(str): The vocabulary filter name. The name must be unique within the account that contains it. If you try to create a vocabulary filter with the same name as another vocabulary filter, you get a ConflictException error.
        language_code(str): The language code of the words in the vocabulary filter. All words in the filter must be in the same language. The vocabulary filter can only be used with transcription jobs in the specified language.
        words(List, optional): The words to use in the vocabulary filter. Only use characters from the character set defined for custom vocabularies. For a list of character sets, see Character Sets for Custom Vocabularies. If you provide a list of words in the Words parameter, you can't use the VocabularyFilterFileUri parameter. Defaults to None.
        vocabulary_filter_file_uri(str, optional): The Amazon S3 location of a text file used as input to create the vocabulary filter. Only use characters from the character set defined for custom vocabularies. For a list of character sets, see Character Sets for Custom Vocabularies. The specified file must be less than 50 KB of UTF-8 characters. If you provide the location of a list of words in the VocabularyFilterFileUri parameter, you can't use the Words parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.filter_.create(
                ctx, vocabulary_filter_name=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.filter.create vocabulary_filter_name=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="create_vocabulary_filter",
        op_kwargs={
            "VocabularyFilterName": vocabulary_filter_name,
            "LanguageCode": language_code,
            "Words": words,
            "VocabularyFilterFileUri": vocabulary_filter_file_uri,
        },
    )


async def delete(hub, ctx, vocabulary_filter_name: str) -> None:
    r"""
    **Autogenerated function**

    Removes a vocabulary filter.

    Args:
        vocabulary_filter_name(str): The name of the vocabulary filter to remove.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.filter_.delete(
                ctx, vocabulary_filter_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.filter.delete vocabulary_filter_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="delete_vocabulary_filter",
        op_kwargs={"VocabularyFilterName": vocabulary_filter_name},
    )


async def get(hub, ctx, vocabulary_filter_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a vocabulary filter.

    Args:
        vocabulary_filter_name(str): The name of the vocabulary filter for which to return information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.filter_.get(
                ctx, vocabulary_filter_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.filter.get vocabulary_filter_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="get_vocabulary_filter",
        op_kwargs={"VocabularyFilterName": vocabulary_filter_name},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, name_contains: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about vocabulary filters.

    Args:
        next_token(str, optional): If the result of the previous request to ListVocabularyFilters was truncated, include the NextToken to fetch the next set of collections. Defaults to None.
        max_results(int, optional): The maximum number of filters to return in the response. If there are fewer results in the list, this response contains only the actual results. Defaults to None.
        name_contains(str, optional): Filters the response so that it only contains vocabulary filters whose name contains the specified string. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.filter_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.filter.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="list_vocabulary_filters",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "NameContains": name_contains,
        },
    )


async def update(
    hub,
    ctx,
    vocabulary_filter_name: str,
    words: List = None,
    vocabulary_filter_file_uri: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a vocabulary filter with a new list of filtered words.

    Args:
        vocabulary_filter_name(str): The name of the vocabulary filter to update. If you try to update a vocabulary filter with the same name as another vocabulary filter, you get a ConflictException error.
        words(List, optional): The words to use in the vocabulary filter. Only use characters from the character set defined for custom vocabularies. For a list of character sets, see Character Sets for Custom Vocabularies. If you provide a list of words in the Words parameter, you can't use the VocabularyFilterFileUri parameter. Defaults to None.
        vocabulary_filter_file_uri(str, optional): The Amazon S3 location of a text file used as input to create the vocabulary filter. Only use characters from the character set defined for custom vocabularies. For a list of character sets, see Character Sets for Custom Vocabularies. The specified file must be less than 50 KB of UTF-8 characters. If you provide the location of a list of words in the VocabularyFilterFileUri parameter, you can't use the Words parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transcribe.vocabulary.filter_.update(
                ctx, vocabulary_filter_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transcribe.vocabulary.filter.update vocabulary_filter_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transcribe",
        operation="update_vocabulary_filter",
        op_kwargs={
            "VocabularyFilterName": vocabulary_filter_name,
            "Words": words,
            "VocabularyFilterFileUri": vocabulary_filter_file_uri,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, load_balancer_name: str, certificate_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a Transport Layer Security (TLS) certificate to your load balancer. TLS is just an updated, more secure version of Secure Socket Layer (SSL). Once you create and validate your certificate, you can attach it to your load balancer. You can also use this API to rotate the certificates on your account. Use the AttachLoadBalancerTlsCertificate action with the non-attached certificate, and it will replace the existing one and become the attached certificate. The AttachLoadBalancerTlsCertificate operation supports tag-based access control via resource tags applied to the resource identified by load balancer name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The name of the load balancer to which you want to associate the SSL/TLS certificate.
        certificate_name(str): The name of your SSL/TLS certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.tls_certificate.attach(
                ctx, load_balancer_name=value, certificate_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.tls_certificate.attach load_balancer_name=value, certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="attach_load_balancer_tls_certificate",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "certificateName": certificate_name,
        },
    )


async def create(
    hub,
    ctx,
    load_balancer_name: str,
    certificate_name: str,
    certificate_domain_name: str,
    certificate_alternative_names: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an SSL/TLS certificate for an Amazon Lightsail load balancer. TLS is just an updated, more secure version of Secure Socket Layer (SSL). The CreateLoadBalancerTlsCertificate operation supports tag-based access control via resource tags applied to the resource identified by load balancer name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The load balancer name where you want to create the SSL/TLS certificate.
        certificate_name(str): The SSL/TLS certificate name. You can have up to 10 certificates in your account at one time. Each Lightsail load balancer can have up to 2 certificates associated with it at one time. There is also an overall limit to the number of certificates that can be issue in a 365-day period. For more information, see Limits.
        certificate_domain_name(str): The domain name (e.g., example.com) for your SSL/TLS certificate.
        certificate_alternative_names(List, optional): An array of strings listing alternative domains and subdomains for your SSL/TLS certificate. Lightsail will de-dupe the names for you. You can have a maximum of 9 alternative names (in addition to the 1 primary domain). We do not support wildcards (e.g., *.example.com). Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.tls_certificate.create(
                ctx, load_balancer_name=value, certificate_name=value, certificate_domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.tls_certificate.create load_balancer_name=value, certificate_name=value, certificate_domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_load_balancer_tls_certificate",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "certificateName": certificate_name,
            "certificateDomainName": certificate_domain_name,
            "certificateAlternativeNames": certificate_alternative_names,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, load_balancer_name: str, certificate_name: str, force: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an SSL/TLS certificate associated with a Lightsail load balancer. The DeleteLoadBalancerTlsCertificate operation supports tag-based access control via resource tags applied to the resource identified by load balancer name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        load_balancer_name(str): The load balancer name.
        certificate_name(str): The SSL/TLS certificate name.
        force(bool, optional): When true, forces the deletion of an SSL/TLS certificate. There can be two certificates associated with a Lightsail load balancer: the primary and the backup. The force parameter is required when the primary SSL/TLS certificate is in use by an instance attached to the load balancer. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.tls_certificate.delete(
                ctx, load_balancer_name=value, certificate_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.tls_certificate.delete load_balancer_name=value, certificate_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_load_balancer_tls_certificate",
        op_kwargs={
            "loadBalancerName": load_balancer_name,
            "certificateName": certificate_name,
            "force": force,
        },
    )


async def get_all(hub, ctx, load_balancer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the TLS certificates that are associated with the specified Lightsail load balancer. TLS is just an updated, more secure version of Secure Socket Layer (SSL). You can have a maximum of 2 certificates associated with a Lightsail load balancer. One is active and the other is inactive.

    Args:
        load_balancer_name(str): The name of the load balancer you associated with your SSL/TLS certificate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.load_balancer.tls_certificate.get_all(
                ctx, load_balancer_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.load_balancer.tls_certificate.get_all load_balancer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_load_balancer_tls_certificates",
        op_kwargs={"loadBalancerName": load_balancer_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    type_name: str,
    field_name: str,
    data_source_name: str = None,
    request_mapping_template: str = None,
    response_mapping_template: str = None,
    kind: str = None,
    pipeline_config: Dict = None,
    sync_config: Dict = None,
    caching_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Resolver object. A resolver converts incoming requests into a format that a data source can understand and converts the data source's responses into GraphQL.

    Args:
        api_id(str): The ID for the GraphQL API for which the resolver is being created.
        type_name(str): The name of the Type.
        field_name(str): The name of the field to attach the resolver to.
        data_source_name(str, optional): The name of the data source for which the resolver is being created. Defaults to None.
        request_mapping_template(str, optional): The mapping template to be used for requests. A resolver uses a request mapping template to convert a GraphQL expression into a format that a data source can understand. Mapping templates are written in Apache Velocity Template Language (VTL). VTL request mapping templates are optional when using a Lambda data source. For all other data sources, VTL request and response mapping templates are required. Defaults to None.
        response_mapping_template(str, optional): The mapping template to be used for responses from the data source. Defaults to None.
        kind(str, optional): The resolver type.    UNIT: A UNIT resolver type. A UNIT resolver is the default resolver type. A UNIT resolver enables you to execute a GraphQL query against a single data source.    PIPELINE: A PIPELINE resolver type. A PIPELINE resolver enables you to execute a series of Function in a serial manner. You can use a pipeline resolver to execute a GraphQL query against multiple data sources.  . Defaults to None.
        pipeline_config(Dict, optional): The PipelineConfig. Defaults to None.
        sync_config(Dict, optional): The SyncConfig for a resolver attached to a versioned datasource. Defaults to None.
        caching_config(Dict, optional): The caching configuration for the resolver. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.resolver.init.create(
                ctx, api_id=value, type_name=value, field_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.resolver.init.create api_id=value, type_name=value, field_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="create_resolver",
        op_kwargs={
            "apiId": api_id,
            "typeName": type_name,
            "fieldName": field_name,
            "dataSourceName": data_source_name,
            "requestMappingTemplate": request_mapping_template,
            "responseMappingTemplate": response_mapping_template,
            "kind": kind,
            "pipelineConfig": pipeline_config,
            "syncConfig": sync_config,
            "cachingConfig": caching_config,
        },
    )


async def delete(hub, ctx, api_id: str, type_name: str, field_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Resolver object.

    Args:
        api_id(str): The API ID.
        type_name(str): The name of the resolver type.
        field_name(str): The resolver field name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.resolver.init.delete(
                ctx, api_id=value, type_name=value, field_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.resolver.init.delete api_id=value, type_name=value, field_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="delete_resolver",
        op_kwargs={"apiId": api_id, "typeName": type_name, "fieldName": field_name},
    )


async def get(hub, ctx, api_id: str, type_name: str, field_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a Resolver object.

    Args:
        api_id(str): The API ID.
        type_name(str): The resolver type name.
        field_name(str): The resolver field name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.resolver.init.get(
                ctx, api_id=value, type_name=value, field_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.resolver.init.get api_id=value, type_name=value, field_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="get_resolver",
        op_kwargs={"apiId": api_id, "typeName": type_name, "fieldName": field_name},
    )


async def list_all(
    hub,
    ctx,
    api_id: str,
    type_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the resolvers for a given API and type.

    Args:
        api_id(str): The API ID.
        type_name(str): The type name.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. . Defaults to None.
        max_results(int, optional): The maximum number of results you want the request to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.resolver.init.list_all(
                ctx, api_id=value, type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.resolver.init.list_all api_id=value, type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="list_resolvers",
        op_kwargs={
            "apiId": api_id,
            "typeName": type_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    api_id: str,
    type_name: str,
    field_name: str,
    data_source_name: str = None,
    request_mapping_template: str = None,
    response_mapping_template: str = None,
    kind: str = None,
    pipeline_config: Dict = None,
    sync_config: Dict = None,
    caching_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Resolver object.

    Args:
        api_id(str): The API ID.
        type_name(str): The new type name.
        field_name(str): The new field name.
        data_source_name(str, optional): The new data source name. Defaults to None.
        request_mapping_template(str, optional): The new request mapping template. A resolver uses a request mapping template to convert a GraphQL expression into a format that a data source can understand. Mapping templates are written in Apache Velocity Template Language (VTL). VTL request mapping templates are optional when using a Lambda data source. For all other data sources, VTL request and response mapping templates are required. Defaults to None.
        response_mapping_template(str, optional): The new response mapping template. Defaults to None.
        kind(str, optional): The resolver type.    UNIT: A UNIT resolver type. A UNIT resolver is the default resolver type. A UNIT resolver enables you to execute a GraphQL query against a single data source.    PIPELINE: A PIPELINE resolver type. A PIPELINE resolver enables you to execute a series of Function in a serial manner. You can use a pipeline resolver to execute a GraphQL query against multiple data sources.  . Defaults to None.
        pipeline_config(Dict, optional): The PipelineConfig. Defaults to None.
        sync_config(Dict, optional): The SyncConfig for a resolver attached to a versioned datasource. Defaults to None.
        caching_config(Dict, optional): The caching configuration for the resolver. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.resolver.init.update(
                ctx, api_id=value, type_name=value, field_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.resolver.init.update api_id=value, type_name=value, field_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="update_resolver",
        op_kwargs={
            "apiId": api_id,
            "typeName": type_name,
            "fieldName": field_name,
            "dataSourceName": data_source_name,
            "requestMappingTemplate": request_mapping_template,
            "responseMappingTemplate": response_mapping_template,
            "kind": kind,
            "pipelineConfig": pipeline_config,
            "syncConfig": sync_config,
            "cachingConfig": caching_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    channel_arn: str,
    single_master_channel_endpoint_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides an endpoint for the specified signaling channel to send and receive messages. This API uses the SingleMasterChannelEndpointConfiguration input parameter, which consists of the Protocols and Role properties.  Protocols is used to determine the communication mechanism. For example, if you specify WSS as the protocol, this API produces a secure websocket endpoint. If you specify HTTPS as the protocol, this API generates an HTTPS endpoint.   Role determines the messaging permissions. A MASTER role results in this API generating an endpoint that a client can use to communicate with any of the viewers on the channel. A VIEWER role results in this API generating an endpoint that a client can use to communicate only with a MASTER.

    Args:
        channel_arn(str): The Amazon Resource Name (ARN) of the signalling channel for which you want to get an endpoint.
        single_master_channel_endpoint_configuration(Dict, optional): A structure containing the endpoint configuration for the SINGLE_MASTER channel type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.signaling_channel.endpoint.get(
                ctx, channel_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.signaling_channel.endpoint.get channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="get_signaling_channel_endpoint",
        op_kwargs={
            "ChannelARN": channel_arn,
            "SingleMasterChannelEndpointConfiguration": single_master_channel_endpoint_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    name: str,
    solution_version_arn: str,
    min_provisioned_tps: int = None,
    campaign_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a campaign by deploying a solution version. When a client calls the GetRecommendations and GetPersonalizedRanking APIs, a campaign is specified in the request.  Minimum Provisioned TPS and Auto-Scaling  A transaction is a single GetRecommendations or GetPersonalizedRanking call. Transactions per second (TPS) is the throughput and unit of billing for Amazon Personalize. The minimum provisioned TPS (minProvisionedTPS) specifies the baseline throughput provisioned by Amazon Personalize, and thus, the minimum billing charge.   If your TPS increases beyond minProvisionedTPS, Amazon Personalize auto-scales the provisioned capacity up and down, but never below minProvisionedTPS. There's a short time delay while the capacity is increased that might cause loss of transactions. The actual TPS used is calculated as the average requests/second within a 5-minute window. You pay for maximum of either the minimum provisioned TPS or the actual TPS. We recommend starting with a low minProvisionedTPS, track your usage using Amazon CloudWatch metrics, and then increase the minProvisionedTPS as necessary.  Status  A campaign can be in one of the following states:   CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED   DELETE PENDING > DELETE IN_PROGRESS   To get the campaign status, call DescribeCampaign.  Wait until the status of the campaign is ACTIVE before asking the campaign for recommendations.   Related APIs     ListCampaigns     DescribeCampaign     UpdateCampaign     DeleteCampaign

    Args:
        name(str): A name for the new campaign. The campaign name must be unique within your account.
        solution_version_arn(str): The Amazon Resource Name (ARN) of the solution version to deploy.
        min_provisioned_tps(int, optional): Specifies the requested minimum provisioned transactions (recommendations) per second that Amazon Personalize will support. Defaults to None.
        campaign_config(Dict, optional): The configuration details of a campaign. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.campaign.create(
                ctx, name=value, solution_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.campaign.create name=value, solution_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="create_campaign",
        op_kwargs={
            "name": name,
            "solutionVersionArn": solution_version_arn,
            "minProvisionedTPS": min_provisioned_tps,
            "campaignConfig": campaign_config,
        },
    )


async def delete(hub, ctx, campaign_arn: str) -> None:
    r"""
    **Autogenerated function**

    Removes a campaign by deleting the solution deployment. The solution that the campaign is based on is not deleted and can be redeployed when needed. A deleted campaign can no longer be specified in a GetRecommendations request. For more information on campaigns, see CreateCampaign.

    Args:
        campaign_arn(str): The Amazon Resource Name (ARN) of the campaign to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.campaign.delete(ctx, campaign_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.campaign.delete campaign_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="delete_campaign",
        op_kwargs={"campaignArn": campaign_arn},
    )


async def describe(hub, ctx, campaign_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the given campaign, including its status. A campaign can be in one of the following states:   CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED   DELETE PENDING > DELETE IN_PROGRESS   When the status is CREATE FAILED, the response includes the failureReason key, which describes why. For more information on campaigns, see CreateCampaign.

    Args:
        campaign_arn(str): The Amazon Resource Name (ARN) of the campaign.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.campaign.describe(ctx, campaign_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.campaign.describe campaign_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="describe_campaign",
        op_kwargs={"campaignArn": campaign_arn},
    )


async def list_all(
    hub, ctx, solution_arn: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of campaigns that use the given solution. When a solution is not specified, all the campaigns associated with the account are listed. The response provides the properties for each campaign, including the Amazon Resource Name (ARN). For more information on campaigns, see CreateCampaign.

    Args:
        solution_arn(str, optional): The Amazon Resource Name (ARN) of the solution to list the campaigns for. When a solution is not specified, all the campaigns associated with the account are listed. Defaults to None.
        next_token(str, optional): A token returned from the previous call to ListCampaigns for getting the next set of campaigns (if they exist). Defaults to None.
        max_results(int, optional): The maximum number of campaigns to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.campaign.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.campaign.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="list_campaigns",
        op_kwargs={
            "solutionArn": solution_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    campaign_arn: str,
    solution_version_arn: str = None,
    min_provisioned_tps: int = None,
    campaign_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a campaign by either deploying a new solution or changing the value of the campaign's minProvisionedTPS parameter. To update a campaign, the campaign status must be ACTIVE or CREATE FAILED. Check the campaign status using the DescribeCampaign API.  You must wait until the status of the updated campaign is ACTIVE before asking the campaign for recommendations.  For more information on campaigns, see CreateCampaign.

    Args:
        campaign_arn(str): The Amazon Resource Name (ARN) of the campaign.
        solution_version_arn(str, optional): The ARN of a new solution version to deploy. Defaults to None.
        min_provisioned_tps(int, optional): Specifies the requested minimum provisioned transactions (recommendations) per second that Amazon Personalize will support. Defaults to None.
        campaign_config(Dict, optional): The configuration details of a campaign. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.personalize.campaign.update(ctx, campaign_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.personalize.campaign.update campaign_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="personalize",
        operation="update_campaign",
        op_kwargs={
            "campaignArn": campaign_arn,
            "solutionVersionArn": solution_version_arn,
            "minProvisionedTPS": min_provisioned_tps,
            "campaignConfig": campaign_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def complete(
    hub,
    ctx,
    repository_name: str,
    upload_id: str,
    layer_digests: List,
    registry_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Informs Amazon ECR that the image layer upload has completed for a specified registry, repository name, and upload ID. You can optionally provide a sha256 digest of the image layer for data validation purposes. When an image is pushed, the CompleteLayerUpload API is called once per each new image layer to verify that the upload has completed.  This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the docker CLI to pull, tag, and push images.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry to which to upload layers. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to associate with the image layer.
        upload_id(str): The upload ID from a previous InitiateLayerUpload operation to associate with the image layer.
        layer_digests(List): The sha256 digest of the image layer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.layer.upload.complete(
                ctx, repository_name=value, upload_id=value, layer_digests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.layer.upload.complete repository_name=value, upload_id=value, layer_digests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="complete_layer_upload",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "uploadId": upload_id,
            "layerDigests": layer_digests,
        },
    )


async def initiate(hub, ctx, repository_name: str, registry_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Notifies Amazon ECR that you intend to upload an image layer. When an image is pushed, the InitiateLayerUpload API is called once per image layer that has not already been uploaded. Whether or not an image layer has been uploaded is determined by the BatchCheckLayerAvailability API action.  This operation is used by the Amazon ECR proxy and is not generally used by customers for pulling and pushing images. In most cases, you should use the docker CLI to pull, tag, and push images.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry to which you intend to upload layers. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to which you intend to upload layers.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.layer.upload.initiate(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.layer.upload.initiate repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="initiate_layer_upload",
        op_kwargs={"registryId": registry_id, "repositoryName": repository_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    max_results: int = None,
    next_token: str = None,
    public_ips: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes your Elastic IP addresses that are being moved to the EC2-VPC platform, or that are being restored to the EC2-Classic platform. This request does not return information about any other Elastic IP addresses in your account.

    Args:
        filters(List, optional): One or more filters.    moving-status - The status of the Elastic IP address (MovingToVpc | RestoringToClassic).  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1000; if MaxResults is given a value outside of this range, an error is returned. Default: If no value is provided, the default is 1000. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        public_ips(List, optional): One or more Elastic IP addresses. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.moving_address.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.moving_address.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_moving_addresses",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "MaxResults": max_results,
            "NextToken": next_token,
            "PublicIps": public_ips,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def apply(hub, ctx, published_schema_arn: str, directory_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Copies the input published schema, at the specified version, into the Directory with the same name and version as that of the published schema.

    Args:
        published_schema_arn(str): Published schema Amazon Resource Name (ARN) that needs to be copied. For more information, see arns.
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory into which the schema is copied. For more information, see arns.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.schema.init.apply(
                ctx, published_schema_arn=value, directory_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.schema.init.apply published_schema_arn=value, directory_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="apply_schema",
        op_kwargs={
            "PublishedSchemaArn": published_schema_arn,
            "DirectoryArn": directory_arn,
        },
    )


async def create(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new schema in a development state. A schema can exist in three phases:    Development: This is a mutable phase of the schema. All new schemas are in the development phase. Once the schema is finalized, it can be published.    Published: Published schemas are immutable and have a version associated with them.    Applied: Applied schemas are mutable in a way that allows you to add new schema facets. You can also add new, nonrequired attributes to existing schema facets. You can apply only published schemas to directories.

    Args:
        name(str): The name that is associated with the schema. This is unique to each account and in each region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.schema.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.schema.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="create_schema",
        op_kwargs={"Name": name},
    )


async def delete(hub, ctx, schema_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a given schema. Schemas in a development and published state can only be deleted.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) of the development schema. For more information, see arns.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.schema.init.delete(ctx, schema_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.schema.init.delete schema_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="delete_schema",
        op_kwargs={"SchemaArn": schema_arn},
    )


async def publish(
    hub,
    ctx,
    development_schema_arn: str,
    version: str,
    minor_version: str = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Publishes a development schema with a major version and a recommended minor version.

    Args:
        development_schema_arn(str): The Amazon Resource Name (ARN) that is associated with the development schema. For more information, see arns.
        version(str): The major version under which the schema will be published. Schemas have both a major and minor version associated with them.
        minor_version(str, optional): The minor version under which the schema will be published. This parameter is recommended. Schemas have both a major and minor version associated with them. Defaults to None.
        name(str, optional): The new name under which the schema will be published. If this is not provided, the development schema is considered. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.schema.init.publish(
                ctx, development_schema_arn=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.schema.init.publish development_schema_arn=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="publish_schema",
        op_kwargs={
            "DevelopmentSchemaArn": development_schema_arn,
            "Version": version,
            "MinorVersion": minor_version,
            "Name": name,
        },
    )


async def update(hub, ctx, schema_arn: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the schema name with a new name. Only development schema names can be updated.

    Args:
        schema_arn(str): The Amazon Resource Name (ARN) of the development schema. For more information, see arns.
        name(str): The name of the schema.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.schema.init.update(
                ctx, schema_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.schema.init.update schema_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="update_schema",
        op_kwargs={"SchemaArn": schema_arn, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, webhook_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes the connection between the webhook that was created by CodePipeline and the external tool with events to be detected. Currently supported only for webhooks that target an action type of GitHub.

    Args:
        webhook_name(str, optional): The name of the webhook you want to deregister. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.webhook.with_third_party.deregister(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.webhook.with_third_party.deregister
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="deregister_webhook_with_third_party",
        op_kwargs={"webhookName": webhook_name},
    )


async def register(hub, ctx, webhook_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Configures a connection between the webhook that was created and the external tool with events to be detected.

    Args:
        webhook_name(str, optional): The name of an existing webhook created with PutWebhook to register with a supported third party. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codepipeline.webhook.with_third_party.register(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codepipeline.webhook.with_third_party.register
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codepipeline",
        operation="register_webhook_with_third_party",
        op_kwargs={"webhookName": webhook_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "for_permission_set"


async def get(hub, ctx, instance_arn: str, permission_set_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Obtains the inline policy assigned to the permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        permission_set_arn(str): The ARN of the permission set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.inline_policy.for_permission_set_.get(
                ctx, instance_arn=value, permission_set_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.inline_policy.for_permission_set.get instance_arn=value, permission_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="get_inline_policy_for_permission_set",
        op_kwargs={"InstanceArn": instance_arn, "PermissionSetArn": permission_set_arn},
    )
